import os
import opusutil

class rm_DatasetList:
  """
===========================================================================
Class: rm_DatasetList

Description:
------------
This class describes an entry used to track ingesting datasets during
the archive Ingest process.

Members:
_archive_class_name - determined by OSF data_id or group processing
_dataset_name - determined by OSF dataset or group processing
_sequence - sequence number within a group
_optional - only groups can have optional items
_present - only groups can have missing optional datasets
_missing_ext - dataset is missing at least one required extension
_dads_request_id - formed from sequence and pipe_id 
_directory_path_name - depends on archive class
_file_count - from search in directory path
_Files - files found for the dataset
_install_dir - timestamped directory under directory_path_name

History:
--------
10/01/02 56017 MSwam     first version
===========================================================================
  """
  def __init__(self, dataset, archive_class, sequence_num, directory, pipe_id):
    self._archive_class_name = archive_class
    self._dataset_name = dataset
    self._sequence = sequence_num
    self._optional = 0    # defaults to non-optional
    self._present = 0     # defaults to a missing member
    self._missing_ext = 0  # defaults to nothing missing
    # e.g. OPUS003 (seq is formatted three-digit number)
    self._dads_request_id = pipe_id + str(sequence_num)
    self._directory_path_name = (directory + os.sep + 
                                 archive_class.lower() + os.sep)
    self._file_count = 0
    self._Files = []
    self._install_dir = None

  def addFile(self, fileEntry):
    self._Files.append(fileEntry)
    self._file_count += 1
    self._present = 1

  def dump(self):
    opusutil.PrintMsg("I","rm_DatasetList=>"+self._dataset_name+","+
                      self._archive_class_name+","+
                      "seq="+str(self._sequence)+","+
                      "opt="+str(self._optional)+","+
                      "present="+str(self._present)+","+
                      "missing_ext="+str(self._missing_ext)+","+
                      "dads_request_id="+self._dads_request_id+","+
                      "dir="+self._directory_path_name+","+
                      "install_dir="+str(self._install_dir)+","+
                      "file_count="+str(self._file_count))
    for f in self._Files:
       f.dump()

#========================================================================
# TEST 
# % python rm_DatasetList.py
#========================================================================
if __name__ == "__main__":
   d = rm_DatasetList("u2440101t","wf2",0,"/aaa/bbb/ccc/","OPUS")
   d.dump()
